// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "TiledSprite.hpp"
#include "scene/SceneItem.hpp"

using namespace Dawn;

TiledSprite::TiledSprite(SceneItem *item) :
  SceneItemComponent(item),
  tile(-1),
  tileset(nullptr),
  meshHost(nullptr)
{

}

std::vector<SceneItemComponent*> TiledSprite::getDependencies() {
  if(this->meshHost == nullptr) {
    this->meshHost = this->item->getComponent<QuadMeshHost>();
  }

  return {
    this->meshHost
  };
}

void TiledSprite::onStart() {
  SceneItemComponent::onStart();

  useEffect([&]{
    if(this->meshHost == nullptr || this->tileset == nullptr) return;
    auto tile = this->tileset->getTile(this->tile);
    this->meshHost->uv0 = tile.uv0;
    this->meshHost->uv1 = tile.uv1;
  }, {
    &this->tile,
    &this->meshHost,
    &this->tileset
  })();
}